@@ -16,8 +16,19 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
+
+from google.cloud.automl_v1 import gapic_version as package_version
 
 from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
@@ -167,9 +178,9 @@ class PredictionServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, PredictionServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the prediction service client.
@@ -213,13 +224,13 @@ class PredictionServiceAsyncClient:
 
     async def predict(
         self,
-        request: Union[prediction_service.PredictRequest, dict] = None,
+        request: Optional[Union[prediction_service.PredictRequest, dict]] = None,
         *,
-        name: str = None,
-        payload: data_items.ExamplePayload = None,
-        params: Mapping[str, str] = None,
+        name: Optional[str] = None,
+        payload: Optional[data_items.ExamplePayload] = None,
+        params: Optional[MutableMapping[str, str]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> prediction_service.PredictResponse:
         r"""Perform an online prediction. The prediction result is directly
@@ -291,7 +302,7 @@ class PredictionServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.automl_v1.types.PredictRequest, dict]):
+            request (Optional[Union[google.cloud.automl_v1.types.PredictRequest, dict]]):
                 The request object. Request message for
                 [PredictionService.Predict][google.cloud.automl.v1.PredictionService.Predict].
             name (:class:`str`):
@@ -310,7 +321,7 @@ class PredictionServiceAsyncClient:
                 This corresponds to the ``payload`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            params (:class:`Mapping[str, str]`):
+            params (:class:`MutableMapping[str, str]`):
                 Additional domain-specific parameters, any string must
                 be up to 25000 characters long.
 
@@ -405,14 +416,14 @@ class PredictionServiceAsyncClient:
 
     async def batch_predict(
         self,
-        request: Union[prediction_service.BatchPredictRequest, dict] = None,
+        request: Optional[Union[prediction_service.BatchPredictRequest, dict]] = None,
         *,
-        name: str = None,
-        input_config: io.BatchPredictInputConfig = None,
-        output_config: io.BatchPredictOutputConfig = None,
-        params: Mapping[str, str] = None,
+        name: Optional[str] = None,
+        input_config: Optional[io.BatchPredictInputConfig] = None,
+        output_config: Optional[io.BatchPredictOutputConfig] = None,
+        params: Optional[MutableMapping[str, str]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Perform a batch prediction. Unlike the online
@@ -469,13 +480,13 @@ class PredictionServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.automl_v1.types.BatchPredictRequest, dict]):
+            request (Optional[Union[google.cloud.automl_v1.types.BatchPredictRequest, dict]]):
                 The request object. Request message for
                 [PredictionService.BatchPredict][google.cloud.automl.v1.PredictionService.BatchPredict].
             name (:class:`str`):
@@ -500,7 +511,7 @@ class PredictionServiceAsyncClient:
                 This corresponds to the ``output_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            params (:class:`Mapping[str, str]`):
+            params (:class:`MutableMapping[str, str]`):
                 Additional domain-specific parameters for the
                 predictions, any string must be up to 25000 characters
                 long.
@@ -669,14 +680,9 @@ class PredictionServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-automl",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("PredictionServiceAsyncClient",)
