@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.cloud.automl_v1.types import image
@@ -21,7 +23,12 @@ from google.cloud.automl_v1.types import translation
 from google.protobuf import timestamp_pb2  # type: ignore
 
 
-__protobuf__ = proto.module(package="google.cloud.automl.v1", manifest={"Model",},)
+__protobuf__ = proto.module(
+    package="google.cloud.automl.v1",
+    manifest={
+        "Model",
+    },
+)
 
 
 class Model(proto.Message):
@@ -86,7 +93,7 @@ class Model(proto.Message):
             Used to perform a consistent
             read-modify-write updates. If not set, a blind
             "overwrite" update happens.
-        labels (Sequence[google.cloud.automl_v1.types.Model.LabelsEntry]):
+        labels (MutableMapping[str, str]):
             Optional. The labels with user-defined
             metadata to organize your model.
             Label keys and values can be no longer than 64
@@ -105,52 +112,84 @@ class Model(proto.Message):
         DEPLOYED = 1
         UNDEPLOYED = 2
 
-    translation_model_metadata = proto.Field(
+    translation_model_metadata: translation.TranslationModelMetadata = proto.Field(
         proto.MESSAGE,
         number=15,
         oneof="model_metadata",
         message=translation.TranslationModelMetadata,
     )
-    image_classification_model_metadata = proto.Field(
-        proto.MESSAGE,
-        number=13,
-        oneof="model_metadata",
-        message=image.ImageClassificationModelMetadata,
+    image_classification_model_metadata: image.ImageClassificationModelMetadata = (
+        proto.Field(
+            proto.MESSAGE,
+            number=13,
+            oneof="model_metadata",
+            message=image.ImageClassificationModelMetadata,
+        )
     )
-    text_classification_model_metadata = proto.Field(
-        proto.MESSAGE,
-        number=14,
-        oneof="model_metadata",
-        message=text.TextClassificationModelMetadata,
+    text_classification_model_metadata: text.TextClassificationModelMetadata = (
+        proto.Field(
+            proto.MESSAGE,
+            number=14,
+            oneof="model_metadata",
+            message=text.TextClassificationModelMetadata,
+        )
     )
-    image_object_detection_model_metadata = proto.Field(
-        proto.MESSAGE,
-        number=20,
-        oneof="model_metadata",
-        message=image.ImageObjectDetectionModelMetadata,
+    image_object_detection_model_metadata: image.ImageObjectDetectionModelMetadata = (
+        proto.Field(
+            proto.MESSAGE,
+            number=20,
+            oneof="model_metadata",
+            message=image.ImageObjectDetectionModelMetadata,
+        )
     )
-    text_extraction_model_metadata = proto.Field(
+    text_extraction_model_metadata: text.TextExtractionModelMetadata = proto.Field(
         proto.MESSAGE,
         number=19,
         oneof="model_metadata",
         message=text.TextExtractionModelMetadata,
     )
-    text_sentiment_model_metadata = proto.Field(
+    text_sentiment_model_metadata: text.TextSentimentModelMetadata = proto.Field(
         proto.MESSAGE,
         number=22,
         oneof="model_metadata",
         message=text.TextSentimentModelMetadata,
     )
-    name = proto.Field(proto.STRING, number=1,)
-    display_name = proto.Field(proto.STRING, number=2,)
-    dataset_id = proto.Field(proto.STRING, number=3,)
-    create_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(
-        proto.MESSAGE, number=11, message=timestamp_pb2.Timestamp,
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    display_name: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    dataset_id: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    create_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=11,
+        message=timestamp_pb2.Timestamp,
+    )
+    deployment_state: DeploymentState = proto.Field(
+        proto.ENUM,
+        number=8,
+        enum=DeploymentState,
+    )
+    etag: str = proto.Field(
+        proto.STRING,
+        number=10,
+    )
+    labels: MutableMapping[str, str] = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=34,
     )
-    deployment_state = proto.Field(proto.ENUM, number=8, enum=DeploymentState,)
-    etag = proto.Field(proto.STRING, number=10,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=34,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
