@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 
@@ -353,7 +355,7 @@ class InputConfig(proto.Message):
             The BigQuery location for the input content.
 
             This field is a member of `oneof`_ ``source``.
-        params (Mapping[str, str]):
+        params (MutableMapping[str, str]):
             Additional domain-specific parameters describing the
             semantic of the imported data, any string must be up to
             25000 characters long.
@@ -365,19 +367,19 @@ class InputConfig(proto.Message):
                Allowed values: "1".
     """
 
-    gcs_source = proto.Field(
+    gcs_source: "GcsSource" = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="source",
         message="GcsSource",
     )
-    bigquery_source = proto.Field(
+    bigquery_source: "BigQuerySource" = proto.Field(
         proto.MESSAGE,
         number=3,
         oneof="source",
         message="BigQuerySource",
     )
-    params = proto.MapField(
+    params: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=2,
@@ -556,13 +558,13 @@ class BatchPredictInputConfig(proto.Message):
             This field is a member of `oneof`_ ``source``.
     """
 
-    gcs_source = proto.Field(
+    gcs_source: "GcsSource" = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="source",
         message="GcsSource",
     )
-    bigquery_source = proto.Field(
+    bigquery_source: "BigQuerySource" = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="source",
@@ -582,7 +584,7 @@ class DocumentInputConfig(proto.Message):
             Supported extensions: .PDF.
     """
 
-    gcs_source = proto.Field(
+    gcs_source: "GcsSource" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="GcsSource",
@@ -640,13 +642,13 @@ class OutputConfig(proto.Message):
             This field is a member of `oneof`_ ``destination``.
     """
 
-    gcs_destination = proto.Field(
+    gcs_destination: "GcsDestination" = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="destination",
         message="GcsDestination",
     )
-    bigquery_destination = proto.Field(
+    bigquery_destination: "BigQueryDestination" = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="destination",
@@ -962,13 +964,13 @@ class BatchPredictOutputConfig(proto.Message):
             This field is a member of `oneof`_ ``destination``.
     """
 
-    gcs_destination = proto.Field(
+    gcs_destination: "GcsDestination" = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="destination",
         message="GcsDestination",
     )
-    bigquery_destination = proto.Field(
+    bigquery_destination: "BigQueryDestination" = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="destination",
@@ -1066,7 +1068,7 @@ class ModelExportOutputConfig(proto.Message):
             //cloud.google.com/vision/automl/docs/containers-gcs-quickstart)
 
             -  core_ml - Used for iOS mobile devices.
-        params (Mapping[str, str]):
+        params (MutableMapping[str, str]):
             Additional model-type and format specific parameters
             describing the requirements for the to be exported model
             files, any string must be up to 25000 characters long.
@@ -1076,23 +1078,23 @@ class ModelExportOutputConfig(proto.Message):
                "none" (default), "nvidia".
     """
 
-    gcs_destination = proto.Field(
+    gcs_destination: "GcsDestination" = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="destination",
         message="GcsDestination",
     )
-    gcr_destination = proto.Field(
+    gcr_destination: "GcrDestination" = proto.Field(
         proto.MESSAGE,
         number=3,
         oneof="destination",
         message="GcrDestination",
     )
-    model_format = proto.Field(
+    model_format: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    params = proto.MapField(
+    params: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=2,
@@ -1140,7 +1142,7 @@ class ExportEvaluatedExamplesOutputConfig(proto.Message):
             This field is a member of `oneof`_ ``destination``.
     """
 
-    bigquery_destination = proto.Field(
+    bigquery_destination: "BigQueryDestination" = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="destination",
@@ -1152,14 +1154,14 @@ class GcsSource(proto.Message):
     r"""The Google Cloud Storage location for the input content.
 
     Attributes:
-        input_uris (Sequence[str]):
+        input_uris (MutableSequence[str]):
             Required. Google Cloud Storage URIs to input files, up to
             2000 characters long. Accepted forms:
 
             -  Full object path, e.g. gs://bucket/directory/object.csv
     """
 
-    input_uris = proto.RepeatedField(
+    input_uris: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=1,
     )
@@ -1176,7 +1178,7 @@ class BigQuerySource(proto.Message):
             -  BigQuery path e.g. bq://projectId.bqDatasetId.bqTableId
     """
 
-    input_uri = proto.Field(
+    input_uri: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -1196,7 +1198,7 @@ class GcsDestination(proto.Message):
                is created if it doesn't exist.
     """
 
-    output_uri_prefix = proto.Field(
+    output_uri_prefix: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -1213,7 +1215,7 @@ class BigQueryDestination(proto.Message):
             -  BigQuery path e.g. bq://projectId
     """
 
-    output_uri = proto.Field(
+    output_uri: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -1238,7 +1240,7 @@ class GcrDestination(proto.Message):
             project.
     """
 
-    output_uri = proto.Field(
+    output_uri: str = proto.Field(
         proto.STRING,
         number=1,
     )
