@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.cloud.automl_v1beta1.types import column_spec as gca_column_spec
@@ -73,8 +75,15 @@ class CreateDatasetRequest(proto.Message):
             Required. The dataset to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    dataset = proto.Field(proto.MESSAGE, number=2, message=gca_dataset.Dataset,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    dataset: gca_dataset.Dataset = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gca_dataset.Dataset,
+    )
 
 
 class GetDatasetRequest(proto.Message):
@@ -87,7 +96,10 @@ class GetDatasetRequest(proto.Message):
             retrieve.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListDatasetsRequest(proto.Message):
@@ -120,10 +132,22 @@ class ListDatasetsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=3,)
-    page_size = proto.Field(proto.INT32, number=4,)
-    page_token = proto.Field(proto.STRING, number=6,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ListDatasetsResponse(proto.Message):
@@ -131,7 +155,7 @@ class ListDatasetsResponse(proto.Message):
     [AutoMl.ListDatasets][google.cloud.automl.v1beta1.AutoMl.ListDatasets].
 
     Attributes:
-        datasets (Sequence[google.cloud.automl_v1beta1.types.Dataset]):
+        datasets (MutableSequence[google.cloud.automl_v1beta1.types.Dataset]):
             The datasets read.
         next_page_token (str):
             A token to retrieve next page of results. Pass to
@@ -143,10 +167,15 @@ class ListDatasetsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    datasets = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gca_dataset.Dataset,
+    datasets: MutableSequence[gca_dataset.Dataset] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gca_dataset.Dataset,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class UpdateDatasetRequest(proto.Message):
@@ -161,9 +190,15 @@ class UpdateDatasetRequest(proto.Message):
             The update mask applies to the resource.
     """
 
-    dataset = proto.Field(proto.MESSAGE, number=1, message=gca_dataset.Dataset,)
-    update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    dataset: gca_dataset.Dataset = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gca_dataset.Dataset,
+    )
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -177,7 +212,10 @@ class DeleteDatasetRequest(proto.Message):
             delete.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ImportDataRequest(proto.Message):
@@ -194,8 +232,15 @@ class ImportDataRequest(proto.Message):
             domain specific semantics, if any.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    input_config = proto.Field(proto.MESSAGE, number=3, message=io.InputConfig,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    input_config: io.InputConfig = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=io.InputConfig,
+    )
 
 
 class ExportDataRequest(proto.Message):
@@ -209,8 +254,15 @@ class ExportDataRequest(proto.Message):
             Required. The desired output location.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    output_config = proto.Field(proto.MESSAGE, number=3, message=io.OutputConfig,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    output_config: io.OutputConfig = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=io.OutputConfig,
+    )
 
 
 class GetAnnotationSpecRequest(proto.Message):
@@ -223,7 +275,10 @@ class GetAnnotationSpecRequest(proto.Message):
             spec to retrieve.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class GetTableSpecRequest(proto.Message):
@@ -238,8 +293,15 @@ class GetTableSpecRequest(proto.Message):
             Mask specifying which fields to read.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    field_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    field_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
 
 
 class ListTableSpecsRequest(proto.Message):
@@ -267,11 +329,27 @@ class ListTableSpecsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    field_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,)
-    filter = proto.Field(proto.STRING, number=3,)
-    page_size = proto.Field(proto.INT32, number=4,)
-    page_token = proto.Field(proto.STRING, number=6,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    field_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ListTableSpecsResponse(proto.Message):
@@ -279,7 +357,7 @@ class ListTableSpecsResponse(proto.Message):
     [AutoMl.ListTableSpecs][google.cloud.automl.v1beta1.AutoMl.ListTableSpecs].
 
     Attributes:
-        table_specs (Sequence[google.cloud.automl_v1beta1.types.TableSpec]):
+        table_specs (MutableSequence[google.cloud.automl_v1beta1.types.TableSpec]):
             The table specs read.
         next_page_token (str):
             A token to retrieve next page of results. Pass to
@@ -291,10 +369,15 @@ class ListTableSpecsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    table_specs = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gca_table_spec.TableSpec,
+    table_specs: MutableSequence[gca_table_spec.TableSpec] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gca_table_spec.TableSpec,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class UpdateTableSpecRequest(proto.Message):
@@ -309,9 +392,15 @@ class UpdateTableSpecRequest(proto.Message):
             The update mask applies to the resource.
     """
 
-    table_spec = proto.Field(proto.MESSAGE, number=1, message=gca_table_spec.TableSpec,)
-    update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    table_spec: gca_table_spec.TableSpec = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gca_table_spec.TableSpec,
+    )
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -327,8 +416,15 @@ class GetColumnSpecRequest(proto.Message):
             Mask specifying which fields to read.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    field_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    field_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
 
 
 class ListColumnSpecsRequest(proto.Message):
@@ -356,11 +452,27 @@ class ListColumnSpecsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    field_mask = proto.Field(proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,)
-    filter = proto.Field(proto.STRING, number=3,)
-    page_size = proto.Field(proto.INT32, number=4,)
-    page_token = proto.Field(proto.STRING, number=6,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    field_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ListColumnSpecsResponse(proto.Message):
@@ -368,7 +480,7 @@ class ListColumnSpecsResponse(proto.Message):
     [AutoMl.ListColumnSpecs][google.cloud.automl.v1beta1.AutoMl.ListColumnSpecs].
 
     Attributes:
-        column_specs (Sequence[google.cloud.automl_v1beta1.types.ColumnSpec]):
+        column_specs (MutableSequence[google.cloud.automl_v1beta1.types.ColumnSpec]):
             The column specs read.
         next_page_token (str):
             A token to retrieve next page of results. Pass to
@@ -380,10 +492,15 @@ class ListColumnSpecsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    column_specs = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gca_column_spec.ColumnSpec,
+    column_specs: MutableSequence[gca_column_spec.ColumnSpec] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gca_column_spec.ColumnSpec,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class UpdateColumnSpecRequest(proto.Message):
@@ -398,11 +515,15 @@ class UpdateColumnSpecRequest(proto.Message):
             The update mask applies to the resource.
     """
 
-    column_spec = proto.Field(
-        proto.MESSAGE, number=1, message=gca_column_spec.ColumnSpec,
+    column_spec: gca_column_spec.ColumnSpec = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gca_column_spec.ColumnSpec,
     )
-    update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -418,8 +539,15 @@ class CreateModelRequest(proto.Message):
             Required. The model to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    model = proto.Field(proto.MESSAGE, number=4, message=gca_model.Model,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    model: gca_model.Model = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=gca_model.Model,
+    )
 
 
 class GetModelRequest(proto.Message):
@@ -431,7 +559,10 @@ class GetModelRequest(proto.Message):
             Required. Resource name of the model.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListModelsRequest(proto.Message):
@@ -467,10 +598,22 @@ class ListModelsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=3,)
-    page_size = proto.Field(proto.INT32, number=4,)
-    page_token = proto.Field(proto.STRING, number=6,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ListModelsResponse(proto.Message):
@@ -478,7 +621,7 @@ class ListModelsResponse(proto.Message):
     [AutoMl.ListModels][google.cloud.automl.v1beta1.AutoMl.ListModels].
 
     Attributes:
-        model (Sequence[google.cloud.automl_v1beta1.types.Model]):
+        model (MutableSequence[google.cloud.automl_v1beta1.types.Model]):
             List of models in the requested page.
         next_page_token (str):
             A token to retrieve next page of results. Pass to
@@ -490,8 +633,15 @@ class ListModelsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    model = proto.RepeatedField(proto.MESSAGE, number=1, message=gca_model.Model,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    model: MutableSequence[gca_model.Model] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gca_model.Model,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class DeleteModelRequest(proto.Message):
@@ -504,7 +654,10 @@ class DeleteModelRequest(proto.Message):
             deleted.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeployModelRequest(proto.Message):
@@ -534,19 +687,22 @@ class DeployModelRequest(proto.Message):
             deploy.
     """
 
-    image_object_detection_model_deployment_metadata = proto.Field(
+    image_object_detection_model_deployment_metadata: image.ImageObjectDetectionModelDeploymentMetadata = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="model_deployment_metadata",
         message=image.ImageObjectDetectionModelDeploymentMetadata,
     )
-    image_classification_model_deployment_metadata = proto.Field(
+    image_classification_model_deployment_metadata: image.ImageClassificationModelDeploymentMetadata = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="model_deployment_metadata",
         message=image.ImageClassificationModelDeploymentMetadata,
     )
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UndeployModelRequest(proto.Message):
@@ -559,7 +715,10 @@ class UndeployModelRequest(proto.Message):
             undeploy.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ExportModelRequest(proto.Message):
@@ -577,9 +736,14 @@ class ExportModelRequest(proto.Message):
             configuration.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    output_config = proto.Field(
-        proto.MESSAGE, number=3, message=io.ModelExportOutputConfig,
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    output_config: io.ModelExportOutputConfig = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=io.ModelExportOutputConfig,
     )
 
 
@@ -596,9 +760,14 @@ class ExportEvaluatedExamplesRequest(proto.Message):
             configuration.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    output_config = proto.Field(
-        proto.MESSAGE, number=3, message=io.ExportEvaluatedExamplesOutputConfig,
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    output_config: io.ExportEvaluatedExamplesOutputConfig = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=io.ExportEvaluatedExamplesOutputConfig,
     )
 
 
@@ -612,7 +781,10 @@ class GetModelEvaluationRequest(proto.Message):
             evaluation.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListModelEvaluationsRequest(proto.Message):
@@ -648,10 +820,22 @@ class ListModelEvaluationsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=3,)
-    page_size = proto.Field(proto.INT32, number=4,)
-    page_token = proto.Field(proto.STRING, number=6,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ListModelEvaluationsResponse(proto.Message):
@@ -659,7 +843,7 @@ class ListModelEvaluationsResponse(proto.Message):
     [AutoMl.ListModelEvaluations][google.cloud.automl.v1beta1.AutoMl.ListModelEvaluations].
 
     Attributes:
-        model_evaluation (Sequence[google.cloud.automl_v1beta1.types.ModelEvaluation]):
+        model_evaluation (MutableSequence[google.cloud.automl_v1beta1.types.ModelEvaluation]):
             List of model evaluations in the requested
             page.
         next_page_token (str):
@@ -674,10 +858,17 @@ class ListModelEvaluationsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    model_evaluation = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gca_model_evaluation.ModelEvaluation,
+    model_evaluation: MutableSequence[
+        gca_model_evaluation.ModelEvaluation
+    ] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gca_model_evaluation.ModelEvaluation,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
