@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.cloud.automl_v1beta1.types import classification
@@ -39,8 +41,10 @@ class TextClassificationDatasetMetadata(proto.Message):
             Required. Type of the classification problem.
     """
 
-    classification_type = proto.Field(
-        proto.ENUM, number=1, enum=classification.ClassificationType,
+    classification_type: classification.ClassificationType = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=classification.ClassificationType,
     )
 
 
@@ -53,14 +57,15 @@ class TextClassificationModelMetadata(proto.Message):
             dataset used to train this model.
     """
 
-    classification_type = proto.Field(
-        proto.ENUM, number=3, enum=classification.ClassificationType,
+    classification_type: classification.ClassificationType = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=classification.ClassificationType,
     )
 
 
 class TextExtractionDatasetMetadata(proto.Message):
-    r"""Dataset metadata that is specific to text extraction
-    """
+    r"""Dataset metadata that is specific to text extraction"""
 
 
 class TextExtractionModelMetadata(proto.Message):
@@ -77,7 +82,10 @@ class TextExtractionModelMetadata(proto.Message):
                that is tuned for healthcare applications.
     """
 
-    model_hint = proto.Field(proto.STRING, number=3,)
+    model_hint: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class TextSentimentDatasetMetadata(proto.Message):
@@ -94,12 +102,14 @@ class TextSentimentDatasetMetadata(proto.Message):
             and 10 (inclusive).
     """
 
-    sentiment_max = proto.Field(proto.INT32, number=1,)
+    sentiment_max: int = proto.Field(
+        proto.INT32,
+        number=1,
+    )
 
 
 class TextSentimentModelMetadata(proto.Message):
-    r"""Model metadata that is specific to text sentiment.
-    """
+    r"""Model metadata that is specific to text sentiment."""
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
